@@ -15,13 +15,15 @@ use crate::source::checkpoint::KafkaCheckpointFunction;
 use crate::source::consumer::{create_kafka_consumer, ConsumerRange};
 use crate::source::deserializer::KafkaRecordDeserializerBuilder;
 use crate::source::iterator::KafkaRecordIterator;
+use crate::source::offset_range::OffsetRange;
 use crate::state::PartitionOffset;
-use crate::OffsetRange;
 
 const CREATE_KAFKA_CONNECTION: &'static str = "create_kafka_connection";
 
 #[derive(NamedFunction)]
 pub struct KafkaInputFormat {
+    parallelism: u16,
+
     client_config: ClientConfig,
     topics: Vec<String>,
 
@@ -43,9 +45,11 @@ impl KafkaInputFormat {
         buffer_size: usize,
         offset_range: OffsetRange,
         deserializer_builder: Box<dyn KafkaRecordDeserializerBuilder>,
+        parallelism: u16,
     ) -> Self {
         let schema = deserializer_builder.schema();
         KafkaInputFormat {
+            parallelism,
             client_config,
             topics,
             buffer_size,
@@ -202,6 +206,10 @@ impl InputFormat for KafkaInputFormat {
     fn schema(&self, _input_schema: FnSchema) -> FnSchema {
         self.schema.clone()
     }
+
+    fn parallelism(&self) -> u16 {
+        self.parallelism
+    }
 }
 
 impl CheckpointFunction for KafkaInputFormat {
